@@ -1,5 +1,3 @@
-require 'spec_helper'
-
 describe Gon::Global do
 
   before(:each) do
@@ -18,10 +16,10 @@ describe Gon::Global do
     end
 
     it 'supports all data types' do
-      Gon.global.clear
       Gon.global.int          = 1
       Gon.global.float        = 1.1
       Gon.global.string       = 'string'
+      Gon.global.symbol       = :symbol
       Gon.global.array        = [1, 'string']
       Gon.global.hash_var     = { :a => 1, :b => '2' }
       Gon.global.hash_w_array = { :a => [2, 3] }
@@ -34,18 +32,14 @@ describe Gon::Global do
 
     before(:each) do
       Gon.clear
-      Gon.global.clear
-      expect(ActionView::Base.
-        instance_methods.
-        map(&:to_s).
-        include?('include_gon')).to eq(true)
+      expect(ActionView::Base.instance_methods).to include(:include_gon)
       @base = ActionView::Base.new
       @base.request = request
     end
 
     it 'outputs correct js with an integer' do
       Gon.global.int = 1
-      expect(@base.include_gon).to eq("<script type=\"text/javascript\">" +
+      expect(@base.include_gon).to eq("<script>" +
                                     "\n//<![CDATA[\n" +
                                     "window.gon={};" +
                                     "gon.global={\"int\":1};" +
@@ -56,7 +50,7 @@ describe Gon::Global do
     it 'outputs correct js with an integer and integer in Gon' do
       Gon.int = 1
       Gon.global.int = 1
-      expect(@base.include_gon).to eq("<script type=\"text/javascript\">" +
+      expect(@base.include_gon).to eq("<script>" +
                                     "\n//<![CDATA[\n" +
                                     "window.gon={};" +
                                     "gon.global={\"int\":1};" +
@@ -67,7 +61,7 @@ describe Gon::Global do
 
     it 'outputs correct js with a string' do
       Gon.global.str = %q(a'b"c)
-      expect(@base.include_gon).to eq("<script type=\"text/javascript\">" +
+      expect(@base.include_gon).to eq("<script>" +
                                     "\n//<![CDATA[\n" +
                                     "window.gon={};" +
                                     "gon.global={\"str\":\"a'b\\\"c\"};" +
@@ -78,7 +72,7 @@ describe Gon::Global do
     it 'outputs correct js with a script string' do
       Gon.global.str = %q(</script><script>alert('!')</script>)
       escaped_str = "\\u003c/script\\u003e\\u003cscript\\u003ealert('!')\\u003c/script\\u003e"
-      expect(@base.include_gon).to eq("<script type=\"text/javascript\">" +
+      expect(@base.include_gon).to eq("<script>" +
                                     "\n//<![CDATA[\n" +
                                     "window.gon={};" +
                                     "gon.global={\"str\":\"#{escaped_str}\"};" +
@@ -88,7 +82,7 @@ describe Gon::Global do
 
     it 'outputs correct js with a unicode line separator' do
       Gon.global.str = "\u2028"
-      expect(@base.include_gon).to eq("<script type=\"text/javascript\">" +
+      expect(@base.include_gon).to eq("<script>" +
                                     "\n//<![CDATA[\n" +
                                     "window.gon={};" +
                                     "gon.global={\"str\":\"&#x2028;\"};" +
@@ -99,7 +93,7 @@ describe Gon::Global do
     it 'outputs locally overridden value' do
       Gon.str = 'local value'
       Gon.global.str = 'global value'
-      expect(@base.include_gon(global_root: '')).to eq("<script type=\"text/javascript\">" +
+      expect(@base.include_gon(global_root: '')).to eq("<script>" +
                                      "\n//<![CDATA[\n" +
                                      "window.gon={};" +
                                      "gon.str=\"local value\";" +
@@ -107,18 +101,26 @@ describe Gon::Global do
                                      "</script>")
     end
 
+    it "includes the tag attributes in the script tag" do
+      Gon.global.int = 1
+      expect(@base.include_gon(nonce: 'test')).to eq("<script nonce=\"test\">" +
+                                    "\n//<![CDATA[\n" +
+                                    "window.gon={};" +
+                                    "gon.global={\"int\":1};" +
+                                    "\n//]]>\n" +
+                                  "</script>")
+    end
+
   end
 
   it 'returns exception if try to set public method as variable' do
-    Gon.global.clear
-    expect { Gon.global.all_variables = 123 }.to raise_error
-    expect { Gon.global.rabl = 123 }.to raise_error
+    expect { Gon.global.all_variables = 123 }.to raise_error(RuntimeError)
+    expect { Gon.global.rabl = 123 }.to raise_error(RuntimeError)
   end
 
   context 'with jbuilder and rabl' do
 
     before :each do
-      Gon.global.clear
       controller.instance_variable_set('@objects', objects)
     end
 
@@ -136,8 +138,8 @@ describe Gon::Global do
     end
 
     it 'should throw exception, if use rabl or jbuilder without :template' do
-      expect { Gon.global.rabl }.to raise_error
-      expect { Gon.global.jbuilder }.to raise_error
+      expect { Gon.global.rabl }.to raise_error(RuntimeError)
+      expect { Gon.global.jbuilder }.to raise_error(RuntimeError)
     end
 
   end
